@@ -1,5 +1,6 @@
 import copy
 import collections
+from enum import Enum
 import os
 import sys
 
@@ -1599,3 +1600,39 @@ def test_any_with_discriminant():
         assert_equal(str(e), 'expected bool for dictionary value @ data[\'implementation\'][\'c-value\']')
     else:
         assert False, "Did not raise correct Invalid"
+
+def test_coerce_enum():
+    """Test Coerce Enum"""
+    class Choice(Enum):
+        Easy = 1
+        Medium = 2
+        Hard = 3
+
+    class StringChoice(str, Enum):
+        Easy = "easy"
+        Medium = "medium"
+        Hard = "hard"
+
+    schema = Schema(Coerce(Choice))
+    string_schema = Schema(Coerce(StringChoice))
+
+    # Valid value
+    assert schema(1) == Choice.Easy
+    assert string_schema("easy") == StringChoice.Easy
+
+    # Invalid value
+    try:
+        schema(4)
+    except Invalid as e:
+        assert_equal(str(e),
+                     "expected Choice or one of 1, 2, 3")
+    else:
+        assert False, "Did not raise Invalid for String"
+
+    try:
+        string_schema("hello")
+    except Invalid as e:
+        assert_equal(str(e),
+                     "expected StringChoice or one of 'easy', 'medium', 'hard'")
+    else:
+        assert False, "Did not raise Invalid for String"
